==> owncloud-app-gallery-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/sk_SK.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "Pictures" : "Obrázky",
    "Aborting preview. Could not find the file" : "Ruším náhľad. Súbor nemožno nájsť.",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebola nájdená inštalácia ownCloudu (7 alebo vyššia) {remote}",
    "Invalid ownCloud url" : "Chybná ownCloud url",
    "Gallery view" : "Pohľad galérie",
    "Could not load the description" : "Nemožno načítať popis",
    "Could not load the description: " : "Nemožno načítať popis:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nemožno načítať oznámenie o copyrighte",
    "Copyright notice" : "Oznámenie o copyrighte",
    "Link to copyright document" : "Linka na dokument o copyrighte",
    "This application may not work properly on your browser." : "Aplikácia nemusí vo vašom prehliadači pracovať riadne.",
    "For an improved experience, please install one of the following alternatives" : "Lepšiu skúsenosť získate s jednou z nasledujúcich alternatív",
    "Your browser is not supported!" : "Váš prehliadač nie je podporovaný.",
    "please install one of the following alternatives" : "prosím inštalujte jednu z nasledujúcich alternatív",
    "Configuration error" : "Chyba nastavenia",
    "Error loading slideshow template" : "Chyba pri načítaní šablóny prezentácie",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Chyba</strong> Nie je možné vytvoriť náhľad na súbor.<br>",
    "Next" : "Ďalšia",
    "Play" : "Prehrať",
    "Pause" : "Pauza",
    "Previous" : "Predošlá",
    "Close" : "Zavrieť",
    "Download" : "Sťahovanie",
    "Toggle background" : "Prepnúť pozadie",
    "Shared" : "Zdieľané",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba počas zdieľania",
    "Error while unsharing" : "Chyba počas ukončenia zdieľania",
    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
    "Share" : "Zdieľať",
    "Share link" : "Zdieľať linku",
    "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
    "Link" : "Odkaz",
    "Password protect" : "Chrániť heslom",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
    "Adding user..." : "Pridávam používateľa...",
    "group" : "skupina",
    "remote" : "vzdialený",
    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
    "Unshare" : "Zrušiť zdieľanie",
    "notify by email" : "informovať emailom",
    "can share" : "môže zdieľať",
    "can edit" : "môže upraviť",
    "access control" : "prístupové práva",
    "create" : "vytvoriť",
    "change" : "zmeniť",
    "delete" : "vymazať",
    "Password protected" : "Chránené heslom",
    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
    "Sending ..." : "Odosielam ...",
    "Email sent" : "Email odoslaný",
    "Warning" : "Upozornenie",
    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Sort by date" : "Podľa času",
    "Sort by name" : "Podľa mena",
    "Album information" : "Info o albume",
    "File list" : "Zoznam súborov",
    "Sorry, this file could not be found." : "Ľutujem, súbor sa nenašiel.",
    "Reasons might be:" : "Možné dôvody:",
    "the wrong file ID was provided" : "poskytnuté chybné ID súboru",
    "the file was removed" : "súbor bol odstránený",
    "the file is corrupt" : "súbor je narušený",
    "the encryption key is missing" : "chýba šifrovací kľúč",
    "Here is the error message returned by the server: " : "Server vrátil nasledujúcu chybovú správu:",
    "For more information, please contact your friendly ownCloud administrator." : "Viac informácií získate od vášho priateľského ownCloud správcu.",
    "Sorry, but the server could not fulfill your request." : "Ľutujem, server nedokáže splniť vašu požiadavku.",
    "Possible reasons for the problem:" : "Možné príčiny problému:",
    "a conflicting app was installed" : "inštalovaná konfliktná aplikácia",
    "a required component is missing or was disconnected" : "požadovaný komponent chýba alebo nie je pripojený",
    "the filesystem is not readable" : "súborový systém je nečitateľný",
    "Sorry, this link doesn't seem to work anymore." : "Ľutujem, táto linka už nevyzerá funkčná.",
    "the item was removed" : "položka bola presunutá",
    "the link has expired" : "linka vypršala",
    "sharing is disabled" : "zdieľanie je zakázané",
    "For more information, please ask the person who has sent you this link." : "Viac informácií vám poskytne osoba, ktorá vám tento link poslala.",
    "Add to your ownCloud" : "Pridať do svojho ownCloudu",
    "Picture view" : "Zobrazenie obrázka"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-gallery-9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/gallery/l10n/sk_SK.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "No pictures found" : "Nenašli sa žiadne obrázky",
    "Upload pictures in the files app to display them here" : "Tu sa zobrazia obrázky, ktoré nahráte v aplikácii Súbory",
    "Nothing in here" : "Tu nič nie je",
    "No media files found in this folder" : "V tomto priečinku sa nenachádzajú žiadne multimediálne súbory",
    "Aborting preview. Could not find the file" : "Ruším náhľad. Súbor nemožno nájsť.",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebola nájdená inštalácia ownCloudu (7 alebo vyššia) {remote}",
    "Invalid ownCloud url" : "Chybná ownCloud url",
    "Gallery view" : "Pohľad galérie",
    "Could not load the description" : "Nemožno načítať popis",
    "Could not load the description: " : "Nemožno načítať popis:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nemožno načítať oznámenie o copyrighte",
    "Copyright notice" : "Oznámenie o copyrighte",
    "Link to copyright document" : "Linka na dokument o copyrighte",
    "This application may not work properly on your browser." : "Aplikácia nemusí vo vašom prehliadači pracovať riadne.",
    "For an improved experience, please install one of the following alternatives" : "Lepšiu skúsenosť získate s jednou z nasledujúcich alternatív",
    "Your browser is not supported!" : "Váš prehliadač nie je podporovaný.",
    "please install one of the following alternatives" : "prosím inštalujte jednu z nasledujúcich alternatív",
    "Configuration error" : "Chyba nastavenia",
    "Error loading slideshow template" : "Chyba pri načítaní šablóny prezentácie",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>" : "<strong>Chyba</strong> Nie je možné vytvoriť náhľad na súbor.<br>",
    "Next" : "Ďalšia",
    "Play" : "Prehrať",
    "Pause" : "Pauza",
    "Previous" : "Predošlá",
    "Close" : "Zavrieť",
    "Download" : "Sťahovanie",
    "Toggle background" : "Prepnúť pozadie",
    "Shared" : "Zdieľané",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba počas zdieľania",
    "Error while unsharing" : "Chyba počas ukončenia zdieľania",
    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
    "Shared with you and the group {group} by {owner}" : "Zdieľané s vami a so skupinou {group} používateľom {owner}",
    "Shared with you by {owner}" : "Zdieľané s vami používateľom {owner}",
    "Share with users or groups …" : "Zdieľať s používateľmi alebo skupinami ...",
    "Share with users, groups or remote users …" : "Zdieľať s používateľmi, skupinami alebo vzdialenými používateľmi ...",
    "Share" : "Zdieľať",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Zdieľať s ľuďmi na iných serveroch ownClouds pomocou syntaxe používateľ@doména.com/owncloud",
    "Share link" : "Zdieľať linku",
    "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
    "Link" : "Odkaz",
    "Password protect" : "Chrániť heslom",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
    "Adding user..." : "Pridávam používateľa...",
    "group" : "skupina",
    "remote" : "vzdialený",
    "Resharing is not allowed" : "Zdieľanie už zdieľanej položky nie je povolené",
    "Shared in {item} with {user}" : "Zdieľané v {item} s {user}",
    "Unshare" : "Zrušiť zdieľanie",
    "notify by email" : "informovať emailom",
    "can share" : "môže zdieľať",
    "can edit" : "môže upraviť",
    "access control" : "prístupové práva",
    "create" : "vytvoriť",
    "change" : "zmeniť",
    "delete" : "vymazať",
    "Password protected" : "Chránené heslom",
    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
    "Sending ..." : "Odosielam ...",
    "Email sent" : "Email odoslaný",
    "Warning" : "Upozornenie",
    "This share is password-protected" : "Toto zdieľanie je chránené heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Sort by date" : "Podľa času",
    "Sort by name" : "Podľa mena",
    "Album information" : "Info o albume",
    "File list" : "Zoznam súborov",
    "Sorry, this file could not be found." : "Ľutujem, súbor sa nenašiel.",
    "Reasons might be:" : "Možné dôvody:",
    "the wrong file ID was provided" : "poskytnuté chybné ID súboru",
    "the file was removed" : "súbor bol odstránený",
    "the file is corrupt" : "súbor je narušený",
    "the encryption key is missing" : "chýba šifrovací kľúč",
    "Here is the error message returned by the server: " : "Server vrátil nasledujúcu chybovú správu:",
    "For more information, please contact your friendly ownCloud administrator." : "Viac informácií získate od vášho priateľského ownCloud správcu.",
    "Sorry, but the server could not fulfill your request." : "Ľutujem, server nedokáže splniť vašu požiadavku.",
    "Possible reasons for the problem:" : "Možné príčiny problému:",
    "a conflicting app was installed" : "inštalovaná konfliktná aplikácia",
    "a required component is missing or was disconnected" : "požadovaný komponent chýba alebo nie je pripojený",
    "the filesystem is not readable" : "súborový systém je nečitateľný",
    "Sorry, this link doesn't seem to work anymore." : "Ľutujem, táto linka už nevyzerá funkčná.",
    "the item was removed" : "položka bola presunutá",
    "the link has expired" : "linka vypršala",
    "sharing is disabled" : "zdieľanie je zakázané",
    "For more information, please ask the person who has sent you this link." : "Viac informácií vám poskytne osoba, ktorá vám tento link poslala.",
    "Add to your ownCloud" : "Pridať do svojho ownCloudu",
    "Picture view" : "Zobrazenie obrázka"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
